@@ -31,7 +31,15 @@ describe 'aodh::client' do
         when 'Debian'
           { :client_package_name => 'python3-aodhclient' }
         when 'RedHat'
-          { :client_package_name => 'python-aodhclient' }
+          if facts[:operatingsystem] == 'Fedora'
+            { :client_package_name => 'python3-aodhclient' }
+          else
+            if facts[:operatingsystemmajrelease] > '7'
+              { :client_package_name => 'python3-aodhclient' }
+            else
+              { :client_package_name => 'python-aodhclient' }
+            end
+          end
         end
       end
 
