@@ -21,6 +21,7 @@ describe 'aodh' do
       end
 
       it 'configures rabbit' do
+        is_expected.to contain_aodh_config('DEFAULT/executor_thread_pool_size').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
@@ -44,6 +45,7 @@ describe 'aodh' do
     context 'with overridden parameters' do
       let :params do
         {
+          :executor_thread_pool_size          => '128',
           :default_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
           :rabbit_ha_queues                   => 'undef',
           :rabbit_heartbeat_timeout_threshold => '60',
@@ -59,6 +61,7 @@ describe 'aodh' do
       end
 
       it 'configures rabbit' do
+        is_expected.to contain_aodh_config('DEFAULT/executor_thread_pool_size').with_value('128')
         is_expected.to contain_aodh_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
@@ -77,7 +80,7 @@ describe 'aodh' do
         before { params.merge!( :notification_driver => ['ceilometer.compute.aodh_notifier', 'aodh.openstack.common.notifier.rpc_notifier']) }
 
         it { is_expected.to contain_aodh_config('oslo_messaging_notifications/driver').with_value(
-          'ceilometer.compute.aodh_notifier,aodh.openstack.common.notifier.rpc_notifier'
+          ['ceilometer.compute.aodh_notifier', 'aodh.openstack.common.notifier.rpc_notifier']
         ) }
       end
 
