@@ -44,7 +44,8 @@ describe 'aodh::wsgi::apache' do
           :access_log_format           => 'some format',
           :error_log_file              => '/var/log/httpd/error_log',
           :wsgi_script_dir             => '/var/lib/openstack/cgi-bin/aodh',
-          :wsgi_script_source          => '/my/path/app.wsgi'
+          :wsgi_script_source          => '/my/path/app.wsgi',
+          :vhost_custom_fragment       => 'Timeout 99'
         }
       end
       it { is_expected.to contain_class('aodh::params') }
@@ -61,6 +62,7 @@ describe 'aodh::wsgi::apache' do
         :threads                   => 1,
         :user                      => 'aodh',
         :workers                   => 37,
+        :vhost_custom_fragment     => 'Timeout 99',
         :wsgi_daemon_process       => 'aodh',
         :wsgi_process_display_name => 'aodh',
         :wsgi_process_group        => 'aodh',
